@@ -359,7 +359,7 @@ to 'quit."
           (#t (display (getpid)))
           (_  #t))
 
-        (assert (string? socket-file))
+        (check-argument-types (string? socket-file))
         (spawn-fiber (socket-monitor socket-file on-socket-deletion))
 
         (serve socket))))
@@ -416,6 +416,14 @@ fork in the child process."
     ((_ (binding value) ...)
      (replace-core-bindings! ((binding value) ...) <> ()))))
 
+(define (fibers-version)
+  "Return the version of Fibers being used."
+  ;; The '%fibers-version' variable was introduced in 1.4.0, hence this check.
+  (let ((fibers (resolve-interface '(fibers))))
+    (if (module-defined? fibers '%fibers-version)
+        (module-ref fibers '%fibers-version)
+        "< 1.4")))
+
 
 ;; Main program.
 (define (main . args)
@@ -583,9 +591,10 @@ fork in the child process."
            (set-port-encoding! (%current-service-output-port) "UTF-8")
 
            ;; Log provenance info.
-           (format #t "~a ~a (Guile ~a, ~a)~%"
+           (format #t "~a ~a (Guile ~a, Fibers ~a, ~a)~%"
                    package-name Version
-                   (version) %host-type)
+                   (version) (fibers-version)
+                   %host-type)
 
            (when (= 1 (getpid))
              ;; When running as PID 1, disable hard reboots upon ctrl-alt-del.
