@@ -126,9 +126,18 @@ called with @var{file}."
   ;; Note: Delegate compression to a separate process rather than use an
   ;; in-process compression library to reduce risks of memory corruption or
   ;; leaks and to reduce the attack surface.
+
+  (define (invoke program . args)
+    (let ((status (apply system* program args)))
+      (unless (zero? status)
+        (local-output (l10n "Compression command~{ ~s~} \
+failed with status ~a.")
+                      (cons program args)
+                      status))))
+
   (match method
-    ('gzip (system* %gzip-program "-9" file))
-    ('zstd (system* %zstd-program "-9" "--rm" file))
+    ('gzip (invoke %gzip-program "-9" file))
+    ('zstd (invoke %zstd-program "-9" "--rm" file))
     ('none #f)
     ((? procedure? proc) (proc file))
     (_  #f)))
