@@ -474,7 +474,8 @@ it also reads messages from @code{#:kernel-log-file}, which defaults to
 
 Log messages are passed to @var{message-destination}, a one-argument procedure
 that must return the list of files to write it to.  Write a mark to log files
-when no message has been logged for more than @var{max-silent-time} seconds.
+when no message has been logged for more than @var{max-silent-time} seconds
+(this feature is disabled by setting @var{max-silent-time} to @code{#f}).
 Timestamps in log files are formatted according to @var{date-format}, a format
 string for @code{strftime}, including delimiting space---e.g., @code{\"%c \"}
 for a format identical to that of traditional syslogd implementations.
