@@ -377,10 +377,17 @@ represent the local time on that date, taking DST into account."
 (define* (seconds-to-wait event #:optional (now (current-time time-utc)))
   "Return the number of seconds to wait from @var{now} until the next occurrence
 of @var{event} (the result is an inexact number, always greater than zero)."
-  (let* ((then (next-calendar-event event (time-utc->date now)))
-         (diff (time-difference (date->time-utc then) now)))
-    (+ (time-second diff)
-       (/ (time-nanosecond diff) 1e9))))
+  (let* ((now* (time-utc->date now))
+         (then (next-calendar-event event now*))
+         (diff (time-difference (date->time-utc then) now))
+         (result (+ (time-second diff)
+                    (/ (time-nanosecond diff) 1e9))))
+    ;; If RESULT is zero or negative, that's presumably because of the
+    ;; timezone offset difference between THEN and NOW--e.g., when switching
+    ;; from CET (= UTC+1) to CEST (= UTC+2).  Compensate.
+    (if (<= result 0)
+        (+ result (- (date-zone-offset then) (date-zone-offset now*)))
+        result)))
 
 (define (cron-string->calendar-event str)
   "Convert @var{str}, which contains a Vixie cron date line, into the
