@@ -27,8 +27,15 @@
   #:use-module (ice-9 format)
   #:autoload   (srfi srfi-1) (take)
   #:use-module (srfi srfi-9)
+  #:replace ((define/current-binding . define)
+             (define/current-binding . define*))
   #:export (exception-with-kind-and-args?
             assert
+
+            check-argument-types
+            list-predicate
+            list-of-symbols?
+
             let-loop
 
             ring-buffer
@@ -83,6 +90,23 @@
   ;; This procedure is missing as of Guile 3.0.9.
   (exception-predicate &exception-with-kind-and-args))
 
+(define-syntax-parameter current-binding
+  ;; Binding currently being defined.
+  (identifier-syntax #f))
+
+(define-syntax define/current-binding
+  (syntax-rules ()
+    "Like 'define' and 'define*', but set 'current-binding' to the binding
+being defined, as a symbol."
+    ((_ (name . parameters) body ...)
+     (define/current-binding name
+       (lambda* parameters
+         body ...)))
+    ((_ name exp)
+     (define name
+       (syntax-parameterize ((current-binding (identifier-syntax 'name)))
+         exp)))))
+
 (define-syntax assert
   (lambda (s)
     "Assert that expression @var{exp} does not evaluate to @code{#f}."
@@ -97,8 +121,11 @@
                                                      (number->string line))
                                       "<unknown-location>"))))))
          #`(unless exp
-             (local-output (l10n "~a: Assertion ~s failed.")
-                           #,location 'exp)
+             (if current-binding
+                 (local-output (l10n "~a: Assertion ~s failed in procedure '~a'.")
+                               #,location 'exp current-binding)
+                 (local-output (l10n "~a: Assertion ~s failed.")
+                               #,location 'exp))
              (throw 'assertion-failed)))))))
 
 (define-syntax-rule (let-loop loop ((variable value) ...)
@@ -311,6 +338,41 @@ given MODE."
     (format #t format-string args ...)
     (newline)))
 
+(define (report-wrong-type-argument proc argument value predicate)
+  "Report the given argument type mismatch in call to @var{proc}."
+  (local-output (l10n "In call to '~a', value ~S of argument '~a' has the \
+wrong type (it should match '~a').")
+                proc value argument predicate)
+
+  ;; Also throw the usual 'wrong-type-arg' exception.
+  (throw 'wrong-type-arg proc
+         "Wrong type for argument '~a': ~S"
+         (list argument value)
+         (list value)))
+
+(define-syntax-rule (check-argument-types (predicate argument) ...)
+  "Check that each of the @var{argument}s matches the corresponding type
+@var{predicate}.  Report type mismatches in a comprehensible way."
+  (begin
+    (unless (predicate argument)
+      (report-wrong-type-argument current-binding
+                                  'argument argument 'predicate))
+    ...))
+
+(define (list-predicate predicate)
+  "Return a predicate that returns true when passed a list where each element
+matches @var{predicate}."
+  (define (matches? obj)
+    (match obj
+      ((head . tail)
+       (and (predicate head) (matches? tail)))
+      (() #t)
+      (_ #f)))
+
+  matches?)
+
+(define list-of-symbols? (list-predicate symbol?))
+
 (define* (display-version #:optional (program-name (program-name)))
   (local-output "~a (~a) ~a" program-name package-name Version)
   ;; TRANSLATORS: '~a' is a placeholder for the copyright year.
