@@ -24,10 +24,11 @@ socket="t-socket-$$"
 conf="t-conf-$$"
 log="t-log-$$"
 pid="t-pid-$$"
+service_pid="$PWD/t-service-pid-$$"
 
 herd="herd -s $socket"
 
-trap "cat $log || true; rm -f $log $socket $conf $pid; rm -rf $log_directory;
+trap "cat $log || true; rm -f $log $socket $conf $pid $service_pid; rm -rf $log_directory;
       kill \$main_pid || true" EXIT
 
 cat > "$conf"<<EOF
@@ -41,7 +42,7 @@ cat > "$conf"<<EOF
         (service
           '(log-directory-not-writable)
           #:start (make-forkexec-constructor
-                   '("$SHELL" "-c" "while true; do echo logging; sleep 0.2; done")
+                   '("$SHELL" "-c" "echo \$\$ > $service_pid; while true; do echo trying to log; sleep 0.2; done")
                    #:log-file "$log_directory/read-only/seriously?.log")
           #:stop (make-kill-destructor))))
 EOF
@@ -68,5 +69,6 @@ mkdir -m 0555 "$log_directory/read-only"
 $herd start log-directory-not-writable && false
 $herd status log-directory-not-writable | grep stopped
 grep "Failed to open log file .* for log-directory-not-writable" "$log"
+while kill -0 "$(cat "$service_pid")"; do sleep 0.3; done
 
 $herd status
