@@ -66,6 +66,13 @@ cat > "$conf"<<EOF
          #:stop (make-kill-destructor)
          #:respawn? #f)
 
+       (service
+         '(test-logging-upon-stop)
+         #:start (make-forkexec-constructor
+                  '("$SHELL" "-c" "trap 'while true; do echo refusing to leave; done' TERM; sleep 300"))
+         #:stop (make-kill-destructor #:grace-period 3) ;don't wait too long
+         #:respawn? #f)
+
        (service
 	 ;; Service with built-in logging.
 	 '(test-file-logging)
@@ -90,6 +97,9 @@ shepherd_pid="`cat $pid`"
 while ! test -f "$service_pid" ; do sleep 0.3 ; done
 until $herd status test-file-logging | grep running; do sleep 1; done
 
+# Wait until all the messages have been logged.
+until grep "latin1 garbage" "$service_log"; do sleep 0.3; done
+
 cat "$service_log"
 for message in "STARTING" "STARTED" "café" "latin1 garbage: .* alors"
 do
@@ -133,9 +143,15 @@ fi
 
 rm -f "$service_pid"
 $herd start test-builtin-logging
+
+# Wait until all the messages have been logged.
+until grep "latin1 garbage" "$log"; do sleep 0.3; done
+
 for message in "STARTING" "STARTED" "café" "latin1 garbage: .* alors"
 do
-    grep -E '^2[0-9]{3}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2} \['"$(basename $SHELL)"'\] '"$message" "$log"
+    # Those might be logged as "[sh] MESSAGE" or "sh[123] MESSAGE" depending
+    # on when the 'set-process-id' message is received by the logger.
+    grep -E '^2[0-9]{3}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2} .*'"$(basename $SHELL)"'.* '"$message" "$log"
 done
 
 $herd status test-builtin-logging | grep -v "Log file"
@@ -153,4 +169,16 @@ $herd status root | grep bbbbb
 grep aaaaa "$log"
 grep bbbbb "$log"
 
+# Check what happens with services that start logging once they're stopping.
+# This used to deadlock: <https://issues.guix.gnu.org/77373>.
+$herd start test-logging-upon-stop
+$herd status test-logging-upon-stop | grep running
+pid="`$herd status test-logging-upon-stop | grep PID \
+   | sed -es'/.*PID: \([0-9]\+\)$/\1/g'`"
+kill -0 $pid
+$herd stop test-logging-upon-stop
+$herd status test-logging-upon-stop | grep stopped
+grep "$(basename $SHELL)\[$pid\] refusing to leave" "$log"
+$herd status
+
 $herd stop root
