@@ -41,10 +41,13 @@ cat > "$conf"<<EOF
   ;; Emulate a daemon by forking and exiting right away.
   (quasiquote ("$GUILE" "-c"
     ,(object->string '(when (zero? (primitive-fork))
+                        (format #t "daemon running as PID ~a~%"
+                                   (getpid))
+                        (force-output)
                         (call-with-output-file "$PWD/$service_pid"
                           (lambda (port)
                             (display (getpid) port)))
-                        (sleep 100))))))
+                        (sleep 600))))))
 
 (define %daemon-command-successful
   ;; Purposefully introduce a delay between the time the PID file
@@ -57,7 +60,7 @@ cat > "$conf"<<EOF
                           (lambda (port)
                             (usleep 1500000)
                             (display (getpid) port)))
-                        (sleep 100))))))
+                        (sleep 600))))))
 
 (define nonexistent-pid-file
   ;; Nonexistent PID file in a writable directory, so unlink(2) fails
