@@ -47,7 +47,11 @@ cat > "$conf" <<EOF
 
 (define (message-destination message)
   (pk 'message-destination->
-      (cond ((system-log-message-sender message)
+      (cond ((and=> (system-log-message-sender message)
+                    (lambda (address)
+                      ;; On the Hurd, 'sender' is set even for
+                      ;; AF_UNIX connections.
+                      (not (= AF_UNIX (sockaddr:fam address)))))
              (list "$syslog_remote_file"))
             ((= (system-log-message-facility message)
 		(system-log-facility authorization/private))
@@ -176,6 +180,10 @@ do
     cat "$file"
 done
 
+# The 'status' command should display the socket and kernel log file.
+$herd status system-log | grep "$syslog_socket"
+$herd status system-log | grep "$kmsg"
+
 for file in "$syslog_file" "$syslog_auth_file" "$syslog_debug_file" \
 			   "$syslog_remote_file"
 do
@@ -188,6 +196,10 @@ $herd status system-log -n 12 | grep "sudo: pam_unix"
 $herd status system-log -n 12 | grep "USB disconnect"
 $herd status system-log -n 12 | grep "mtp-probe: "
 
+# End of file has been reached on $kmsg so it should be closed and no longer
+# be polled.
+until grep "Closing .*$kmsg" "$log"; do sleep 0.2; done
+
 # Ensure logs can be rotated.
 $herd start log-rotation
 $herd trigger log-rotation
@@ -236,6 +248,31 @@ do
     test -f "$file"
 done
 
+$herd stop system-log
+
+# Check that an inaccessible #:kernel-log-file does not prevent 'system-log'
+# from starting.
+
+cat > "$conf" <<EOF
+(use-modules (shepherd service system-log)
+             (shepherd endpoints)
+             (srfi srfi-19))
+
+(define %endpoints
+  (list (endpoint (make-socket-address AF_UNIX "$syslog_socket")
+                  #:style SOCK_DGRAM)))
+
+(register-services
+  (list (system-log-service %endpoints
+                            #:kernel-log-file "/does/not/exist")))
+EOF
+
+$herd load root "$conf"
+$herd start system-log
+$herd status system-log | grep "$syslog_socket"
+if $herd status system-log | grep "/does/not/exist"; then false; else true; fi
+grep "Dismissing kernel log.*/does/not/exist" "$log"
+
 $herd stop root
 
 # Local Variables:
