@@ -288,11 +288,28 @@
                   (cons seconds result)))
           (reverse result)))))
 
+(test-equal "seconds-to-wait, CEST -> CET, every 15mn"
+  (append (make-list 11 (* 15 60))    ;Oct. 26th, from 00:00 CEST to 02:45 CEST
+          (list (+ 3600 (* 15 60)))   ;Oct. 26th, from 02:45 CEST to 03:00 CET
+          (make-list 4 (* 15 60)))
+  (let ((event (calendar-event #:minutes '(0 15 30 45))))
+    (let loop ((time (date->time-utc
+                      (make-date 0 0 00 00 26 10 2025 7200))) ;CEST
+               (n 0)
+               (result '()))
+      (if (< n 16)
+          (let ((seconds (inexact->exact (seconds-to-wait event time))))
+            (pk (time-utc->date time))
+            (loop (make-time time-utc 0 (+ seconds (time-second time)))
+                  (+ 1 n)
+                  (cons seconds result)))
+          (reverse result)))))
+
 (test-equal "seconds-to-wait, CET -> CEST, hourly"
   (make-list 24 3600)
   (let ((event (calendar-event #:minutes '(30))))
     (let loop ((time (date->time-utc
-                      (make-date 0 0 30 23 29 10 2025 7200))) ;CEST
+                      (make-date 0 0 30 23 29 03 2025 3600))) ;CET
                (n 0)
                (result '()))
       (if (< n 24)
@@ -302,6 +319,20 @@
                   (cons seconds result)))
           (reverse result)))))
 
+(test-equal "seconds-to-wait, CET -> CEST, every 15mn"
+  (make-list 16 900)
+  (let ((event (calendar-event #:minutes '(0 15 30 45))))
+    (let loop ((time (date->time-utc
+                      (make-date 0 0 00 00 30 03 2025 3600))) ;CET
+               (n 0)
+               (result '()))
+      (if (< n 16)
+          (let ((seconds (inexact->exact (seconds-to-wait event time))))
+            (loop (make-time time-utc 0 (+ seconds (time-second time)))
+                  (+ 1 n)
+                  (cons seconds result)))
+          (reverse result)))))
+
 (let-syntax ((test-cron (syntax-rules ()
                           ((_ str calendar)
                            (test-equal (string-append
